#
# spec file for package python-typeshed
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname typeshed
Name:           python-typeshed
Version:        0.0.1+git.20200312.b44cd294
Release:        1.8
Summary:        Static type information for python modules
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/python/typeshed
Source0:        %{modname}-%{version}.tar.xz
Source1:        python-typeshed-rpmlintrc
BuildRequires:  fdupes
# For tests
BuildRequires:  mypy
BuildRequires:  python-rpm-macros
BuildRequires:  python3-base
BuildRequires:  python3-flake8
BuildRequires:  python3-flake8-bugbear
BuildRequires:  python3-flake8-pyi
#BuildRequires:  python3-pytype
BuildRequires:  python3-typed-ast
Recommends:     mypy
Provides:       python3-typeshed = %{version}
Obsoletes:      python3-typeshed < %{version}
Provides:       python2-typeshed = %{version}
Obsoletes:      python2-typeshed < %{version}
BuildArch:      noarch

%description
Typeshed models function types for the Python standard library
and Python builtins, as well as third party packages.

This data can e.g. be used for static analysis, type checking or
type inference.

This package stores the typedata in %{_datadir}/typeshed

%prep
%autosetup -p1 -n %{modname}-%{version}

rm -r stdlib/2
rm -rv stdlib/*/typing.pyi

%build
# Nothing to build

%install
mkdir -p %{buildroot}/%{_datadir}/typeshed
for dir in stdlib third_party ; do
    cp -r $dir %{buildroot}/%{_datadir}/typeshed/$dir
done
%fdupes %{buildroot}%{_datadir}/typeshed

%check
tests/mypy_test.py || /bin/true
tests/pytype_test.py || /bin/true

%files
%doc CONTRIBUTING.md README.md
%license LICENSE
%{_datadir}/typeshed

%changelog
* Fri Mar 13 2020 Matej Cepl <mcepl@suse.com>
- Hopeless throwing up my arms in the air over the test suite
  always failinig.
* Fri Mar 13 2020 mcepl@suse.com
- Update to version 0.0.1+git.20200312.b44cd294:
  * add chardet.universaldetector (#3734)
  * Fix signature of Connection.iterdump() (#3843)
  * Expand tokenize stub to include Intnumber etc (#3839)
  * Fix remove_child_handler() return type (#3841)
* Wed Mar 11 2020 mcepl@suse.com
- Update to version 0.0.1+git.20200310.5162c536:
  * Make attributes of inspect.ArgSpec optional in Python 3 (#3838)
  * Make PathMatcher correctly exclude paths on windows / any OS without / seperators (#3837)
  * email.mime: add policy arguments (#3827)
  * select: various fixes (#3833)
  * os: fix platform availability (#3832)
  * Have datetime.{date,datetime} define __new__ instead of __init__. (#3829)
  * configparser: add undocumented parameter to SectionProxy.get (#3826)
  * asyncio: add arguments to subprocess_shell (#3825)
  * zipfile.ZipFile: fix fp, extract (#3828)
  * Add parser stubs (#3822)
  * stdlib/3/ast: add visit_* methods to NodeVisitor (#3796)
  * Update imghdr's what() to broadly accept readable binaries instead of BinaryIO (#3811)
  * statistics: fix median_grouped, NormalDist.samples (#3818)
  * argparse: allow passing a callable to ArgumentParser (#3821)
  * asyncore: various fixes (#3820)
  * textwrap: various fixes (#3819)
  * pdb: various fixes (#3817)
  * builtins: add mod to various power functions (#3816)
  * imghdr: h can be None (#3815)
  * string: various fixes (#3814)
  * urllib: various fixes (#3813)
  * bring back attribute types in warnings.WarningMessage (#3810)
  * Add six.moves.collections_abc. (#3812)
  * Improve an annotation in tornado stubs (#3809)
  * Fix stubs for pymysql (#3781)
  * Make `frozenset` covariant (#3808)
  * Mark some obviously incomplete stubs as incomplete (#3807)
  * Add venv module stub (#3783)
  * Fix some issues in cryptography (#3802)
  * stdlib/2and3/builtins: change dict.fromkeys to classmethod (#3798)
  * Annotations for Py3.6 tkinter additions (#3778) (#3797)
  * Add macurl2path stub (#3785)
  * struct: fix arg names, mark positional-only args (#3792)
  * stdlib/3/importlib/metadata: add missing "group" attribute to EntryPoint (#3795)
  * datetime: mark positional-only args (#3791)
  * cgi: various improvements (#3790)
  * ssl: various fixes (#3789)
  * Change annotation of 'function' in Timer.__init__ from Callable[..., None] to Callable[..., Any] (#3788)
  * README.md: better document test_stubtest pitfall (#3793)
  * Added `count` argument to `spop` (#3786)
  * Add this module (#3784)
  * Move tornado to 2and3 (#3780)
  * Move gflags to 2and3 (#3779)
  * stubtest: remove entry from whitelist (#3776)
  * Improve imaplib return types (#3670)
  * stdlib: Remove duplicated Pickler.reducer_override() (#3772)
  * Remove obsolete stubtest whitelist entries (#3773)
  * io: add open_code for py38 (#3769)
  * Include typing for Enum __order__ attribute (#3541)
  * Add missing argument types for xml.sax stubs (#3706)
  * Add missing parameter types for _json (#3710)
  * functools: add singledispatchmethod (#3764)
  * fcntl: various improvements (#3680)
  * modulefinder: fix types for __init__, remove scan_opcodes from py35 (#3765)
  * curses: various fixes (#3771)
  * sre_parse: various fixes (#3758)
  * inspect: various fixes (#3757)
  * json: mark keyword-only args, remove deprecated arg (#3756)
  * difflib: fix various types (#3755)
  * binascii: fix arg names, mark positional-only args (#3754)
  * sys: various fixes (#3762)
  * stdlib: csv.DictReader.fieldnames should be Optional[Sequence[str]] (#3752)
  * import SelectorEventLoop from asyncio.unix_events when not on windows (#3753)
  * cryptography: Make `mode` in `Cipher.__init__` optional (#3751)
  * add _log() method to Logger and LoggerAdapter (#3749)
  * marshal: fix arg name, mark positional-only args (#3759)
  * gc: fix arg name, mark positional-only args (#3760)
  * token: add TYPE_IGNORE, COLONEQUAL for py38 (#3761)
  * tempfile: various fixes (#3763)
  * xml.sax: make_parser accepts iterables in py38 (#3766)
  * ast: add visit_Constant to NodeVisitor (#3767)
  * py_compile: add quiet parameter in py38 (#3768)
  * _imp: mark positional-only args (#3770)
  * inspect._ParameterKind subclasses from enum.IntEnum (#3750)
  * resource: various fixes (#3747)
  * os.path: fix arg names (#3748)
  * re: various fixes (#3746)
  * typeshed: run stubtest in CI (#3727)
  * Add cookie_re / blank_re to py3 tokenize (#3745)
  * Add unquote_to_bytes to py2 six (#3744)
  * Add a few attributes to distutils.ccompiler.CCompiler (#3741)
  * Add cmdclass to distutils.dist.Distribution (#3742)
  * Make `FrameType.f_back` optional (#3740)
  * Fix typing for plistlib.load{,s} (#3738)
  * Update orjson annotations to 2.4.0 (#3737)
  * fix type of distutils.cmd.Command.sub_commands (#3736)
  * Make `itertools.cycle` a type (#3732)
  * Add types for modulefinder instance fields (#3714)
  * Document Annotated and modified get_type_hints (PEP 593) (#3731)
  * platform: update for py38 (#3717)
  * os: fix various arg names (#3726)
  * xml.sax.parse may also take IO[bytes] (#3725)
  * os: fix getenvb, scandir (#3723)
  * io: mark positional-only args (#3721)
  * array: mark positional-only args (#3722)
  * os.register_at_fork: fix signature (#3720)
  * os: mark positional-only args (#3719)
  * signal: mark positional-only args (#3718)
  * uu: fix keyword-only arg (#3716)
  * uuid: add is_safe, Safe UUID (#3715)
  * Add missing parameter types to optparse (#3711)
  * Fix missing types in builtins/__builtin__ (#3705)
  * Add missing return type to read (#3707)
  * Add missing parameter types (#3709)
  * Fix missing type for dataclasses (#3708)
  * Add missing return type in sre_constants (#3712)
  * Add type stubs for asyncio.unix_events (#3664)
  * zipimport: various fixes (#3701)
  * socketserver: Add missing attributes and methods for ForkingMixIn and ThreadingMixin (#3672)
  * _heapq: add key for py2, mark positional-only args (#3696)
  * _random: mark positional-only args (#3697)
  * ast: update for py38 (#3698)
  * collections.Counter: fix default values, allow passing None (#3699)
  * xml.etree.ElementTree: update for py38 (#3700)
  * various errors: fix base class (#3702)
  * argparse: fix RawTextHelpFormatter base class (#3703)
  * Add stub for dateutil.easter (#3695)
  * builtins: fix bytearray.fromhex (#3691)
  * builtins: start can be passed by keyword to sum in 3.8 (#3692)
  * webbrowser: fix platform availability, register (#3694)
  * _curses: fix setupterm, mark positional-only args (#3690)
  * fix arg name to socket.getaddrinfo for py3 (#3689)
  * update SectionProxy.getint()/float/bool stubs to match those of ConfigParser (#3687)
  * Support for PathLike objects in Jinja2 2.11.0 (#3683)
  * Add missing stubs for logging.handlers.WatchedFileHandler. (#3686)
  * make stubs for configparser.getint()/float/bool accept a generically-typed fallback (#3684)
  * sys: Correct types of sys.displayhook, sys.excepthook and variants (#3673)
  * json: mark kwonly args, improve decode (#3679)
  * sqlite3: alias OptimizedUnicode to str for py3 (#3678)
  * turtle: various improvements (#3677)
  * pyexpat: improve ParserCreate, mark positional-only args (#3676)
  * xml: fix default values, mark positional-only args (#3675)
  * dbm: mark positional-only args (#3674)
  * Fix socket.socket.ioctl (#3669)
  * range.index() takes exactly one argument (#3668)
  * asyncio: get_returncode() and get_pipe_transport() can return None (#3663)
  * Fix Crypto.Random.randrange argument types (#3662)
  * accept optional extras in asyncio.BaseTransport init (#3661)
  * subprocess: Make stdin, stdout & stderr Optional for py3 to match py2 (#3652)
  * configparser: fix various arguments (#3632)
  * cmath: fix log, mark positional-only args (#3659)
  * audioop: mark positional-only args (#3658)
  * _thread: fix type of TIMEOUT_MAX (#3657)
  * io: minor fixes for arguments (#3642)
  * builtins.pow: improve annotation (#3647)
  * Pickle 5 (#3636)
  * _codecs: fix various issues (#3649)
  * builtins: mark positional-only args as such (#3648)
  * subprocess: add endtime for py36 and below (#3641)
  * ssl: fix arguments for py36 and below (#3640)
  * http.cookies: add LegalChars for py36 and below (#3639)
  * asyncio: fix various version availability (#3638)
  * Remove consent requirement for third-party stubs (#3643)
  * decimal: remove non-existent args from py3, mark positional-only args (#3633)
  * gflags: Add is_parsed/IsParsed. (#3650)
  * csv: re-export Dialect from _csv (#3613)
  * asyncio: fix SendfileNotAvailableError availability (#3631)
  * hashlib: fix arguments (#3626)
  * heapq: fix arguments (#3645)
  * argparse: various fixes (#3630)
  * difflib: various fixes (#3629)
  * distutils: various fixes (#3634)
  * pprint: fix argument names (#3627)
  * operator: mark positional-only args (#3628)
  * ast: some fixes for py38 (#3625)
  * math: correct argument kinds (#3624)
  * zlib: mark positional only args (#3623)
  * Fix local_addr type (#3622)
  * zipfile: fix various stubs (#3621)
  * update stub for pycurl module (#3530)
  * Add (_)dummy_threading module, identical to threading (#3554)
  * Fill out more attributes in six (#3589)
  * Add missing stubs to pdb and fix related issues in cmd and bdb (#3600)
  * sqlite3: add deterministic parameter to create_function (#3620)
  * platform: update for py38 (#3619)
  * opcode, dis: add jump parameter to stack_effect (#3618)
  * MaildirMessage.set_date accepts a float argument (#3617)
  * zipfile: fix ZipExtFile parameter (#3616)
  * Use overloads for more precise `get_context` type (#3605)
  * fix: add samesite parameter to set_cookie (#3614)
  * logging: update for py38 (#3595)
  * Allow requests to have timeout: Tuple[float, None] (#3612)
  * Change Response.headers from MutableMapping to CaseInsensitiveDict (#3610)
  * added f_fsid: int to os.statvfs_result for >= 3.7 (#3608)
  * Add msvcrt.locking() and associated constants (#3607)
  * binascii: add new parameters to hexlify (#3601)
  * http: update for py38 (#3606)
  * csv: add a return type for things that return (#3604)
  * Make os.statvfs_result inherit from typing.NamedTuple. (#3603)
  * signal: update for py38 (#3602)
  * codecs: add literal overloads for bytes to bytes, str to str codecs (#3599)
  * memoryview: add cast, obj attribute (#3598)
  * Make unittest.FunctionTestCase inherit from TestCase in Python 2. (#3597)
  * Add unittest.result.failfast. (#3596)
  * Unify file descriptor definitions (#3584)
  * Require a newer version of pytype that supports @type_check_only. (#3593)
  * Enable --disallow-subclassing-any (#3591)
  * Fix example code (#3592)
  * Fix argument name of os.link/symlink (#3590)
  * inspect: update _ParameterKind for py38 (#3587)
  * token: add TYPE_COMMENT, remove AWAIT, ASYNC for py37 (#3588)
  * pprint: update for py38, fix kwarg-only parameters (#3585)
  * csv: update DictReader for py38 (#3586)
  * redis: add ping to PubSub (#3583)
  * csv: more precise types, remove TODO (#3581)
  * stdtypes: update for py38 (#3580)
  * zipfile: update for py38 (#3572)
  * BaseHTTPRequestHandler is a subclass of StreamRequestHandler (#3579)
  * jinja2: add Template.{name,filename} (#3578)
  * requests: type responses for PreparedRequest (#3577)
  * Restrict shutil.move src argument to str (#3559)
  * shutil: update which for py38 (#3575)
  * urllib: update for py38 (#3574)
  * Added explicit SSLSocket.accept() definition (#3564)
  * zipfile: fix typo in parameter for PyZipFile (#3573)
  * Fix HTTPConnection timeout type (#3565)
  * Add missing definitions to requests.utils (#3567)
  * Add missing Path.is_mount() introduced in Python 3.7 (#3566)
  * Update int.from_bytes to allow more than sequences (#3571)
  * Add __init__ for subclasses of MappingView in python2 (#3570)
  * socketserver.BaseRequestHandler: add missing hint (#3524)
  * Reflect Python 3.8 updates to the pathlib stdlib module (#3568)
  * Corrected type for "data" in two methods (#3562)
  * Fixed missing methods, wrong names and types (#3560)
* Fri Dec 27 2019 mimi.vx@gmail.com
- Update to version 0.0.1+git.20191227.21a9e696:
  * Update shutil.unpack_archive for 3.7 and up (#3558)
  * Add ast.unparse (#3557)
  * Add antigravity module (#3555)
  * Add __init__ to MappingView and its subclasses (#3528)
  * Remove unused type _HTTPResponse (#3531)
  * Fix RSAPublicNumbers stub (#3505)
  * shutil: Fix rmtree type (#3536)
  * Add typestubs for the warnings module (#3543)
  * Add dbm stubs (#3508)
  * functools: remove first type param of cached_property (#3553)
  * Preserve original type in total_ordering annotation (#3552)
  * Update stubs for Crypto.Random (#3546)
  * Add undocumented methods and make types more specific in 2/unittest (#3550)
  * add jinja macro fields (#3548)
  * add a couple missing stubs and fix an incorrect return type for redis stubs (#3545)
  * Add stubs for winsound module (#3535)
  * Make sure that the context manager for sqlite3.Connection works (#3542)
  * Add __enter__, __exit__ to IMAP4, make __init__ arguments optional (#3540)
  * Add date.__radd__ and datetime.__radd__ (#3539)
* Thu Dec 12 2019 mimi.vx@gmail.com
- Update to version 0.0.1+git.20191209.a06abc5d:
  * Make fieldnames of csv.DictReader Optional (#3534)
  * Update orjson stub from orjson repository(#3532)
  * Update stub for socket module (#3451)
  * Use Literal to improve SpooledTemporaryFile (#3526)
  * random: fix type for sample (#3525)
  * add raw property to BufferedIOBase (#3483)
  * Minor fixes to cryptography (x509) (#3520)
  * Simplify `WatchedFileHandler.__init__` (#3506)
  * Improve warnings stubs (#3501)
  * padding can take an int or an object (PSS.MAX_LENGTH) (#3521)
  * __future__: add _Feature.compiler_flag (#3522)
  * A few return annotations for redis client (#3517)
  * SMTPChannel.push() accepts str (#3516)
  * Optional initial-value parameter for itertools.accumulate() (#3503)
  * In python versions 3.7 and above, re-export Pattern and Match (#3510)
  * builtins.print: make sep and end Optional (#3468) (#3511)
  * Add ImportError constructor arguments (#3512)
  * Fix the signature of unittest.TestCase.assertLogs #3513 (#3514)
  * asyncio/future.pyi - wrap_future loop keyword arg (#3507)
  * Change return type of Message.get_payload() to Any (#3504)
  * Modulefinder stubs (#3497)
  * Type socketserver's RequestHandlerClass as a callable. (#3422)
  * add no_type_check_decorator stub for #2884 (#3460)
  * Add mailcap module (#3482)
  * mailbox: Fix signature of Mailbox.update method (#3493)
  * Refactor warnings.catch_warning to be a class. (#3499)
  * Fix type hints in Template class (#3491)
  * mailbox: Couple small fixes (#3490)
  * timeout argument to urllib.request.urlopen is Optional (#3487)
  * stream argument to pprint.pprint is Optional (#3488)
  * fix incorrect param name in FileIO (#3484)
  * Mostly undo #3372 (#3481)
  * Py37 compileall add invalidation mode (#3476)
  * annotated ZipInfo.from_file (#3478)
  * Add default value to BaseContext.Pipe() (#3479)
  * Mailbox stubs (#3427)
  * Fix some issues in cryptography package (#3474)
  * Add missing elements for multiprocessing.dummy (#3471)
  * distutils.fancy_getopt short option is optional (#3469)
  * Fix type of imp.find_module() (#3465)
  * Add warnings.catch_warning type hints with Literal. (#3464)
  * ast.Dict keys can be None (#3462)
  * Add type hints for audioop module (#3428)
  * Add sys.addaudithook() and audit() (#3455)
  * Run CI tests against win32 and darwin platform (#3457)
  * Fix errors discovered by running typeshed check on Windows (#3456)
  * sys: add pycache_prefix (#3454)
  * Fix type for os.terminal_size to Tuple (#3450)
  * Change the return type of __reduce__ and __reduce_ex__ to Union[str, Tuple[Any, ...]] (#3453)
  * New libs: Change permission requirement to notification (#3443)
  * Add assorted werkzeug type hints (#3444)
  * Use async syntax instead of @coroutine (#3441)
  * Add functools.cached_property (#3439)
  * Add more stubs to redis (pubsub and monitor) (#3442)
  * Add the (deprecated) assertDictContainsSubset() to TestCase. (#3437)
  * Add more stubs for cryptography (#3307)
  * Remove certifi.old_where (#3436)
  * Allow datetime() with a delta=timedelta() in assert(Not)AlmostEqual(s). (#3426)
  * Fix signature of assertRaisesRegexp in unittest (#3434)
  * add timespec arg to datetime.time.isoformat (#3432)
  * Add `sock` attribute for http.client.HTTPConnection in Python 3. (#3429)
  * asyncio: fix windows stubs (#3424)
  * Fix some incorrect/incomplete annotations for redis.client.PubSub (#3408)
  * Add importlib.metadata (Python >= 3.8) (#3346)
  * Copyreg stubs (#3387)
  * Add pytz.FixedOffset (#3393)
  * Add missing Python 3.7 and 3.8 annotations (#3399)
  * Add missing ZipFile constructor arguments (#3414)
  * Add sort_keys param to all dump-like functions in PyYAML (yaml) lib (#3417)
  * Clarify contributions are from people external to the project (#3421)
  * exec, spawn: Allow bytes for environment keys and values. (#3419)
  * Add missing expected_regex parameter to TestCase.assertRaisesRegexp(). (#3418)
  * Allow None for click.core.Context.default_map (#3416)
  * Fix signature of `multiprocessing.get_start_method` (#3415)
  * Fix annotations with literal values (#3411)
  * Update sre_parse module for Python 3.8 (#3412)
  * __init__.pyi: Accept RSAPrivateKey or RSAPublicKey as the key (#3410)
  * Add the `memoryview.release` method (#3405)
  * Update stubs for tabulate (#3391)
  * Add werkzeug.exceptions.FailedDependency (#3403)
  * logging.handlers: Add BufferingHandler.buffer (#3402)
  * Add sys._debugmallocstats (#3401)
  * Added stub for urllib.proxy_bypass() (#3396)
  * Change pprint depth type to Optional[int] (#3392)
  * Convert namedtuples to class syntax (#3321)
  * Adds `posonlyargs` property to `arguments` for python3.8+ (#3390)
  * Require a more recent pytype version. (#3388)
  * Add shlex.shlex.next in Python 2. (#3389)
  * Add missing @property to Response.next() stub (#3384)
  * Fix show_default type in click.option signatures (#3385)
  * Revert __import__ function annotation to return type back to Any (#3383)
  * Change select() stub to accept iterables, not just sequences (#3382)
  * multiprocessing.pool: Fix return of map_async() (#3378)
  * pymysql.Cursor is a context manager (#3379)
  * Don't shadow ast.Tuple with typing.Tuple (#3376)
  * Add PEP 593 (Annotated etc.) typing_extensions stubs (#3369)
  * Make path separator based on OS separator (#3375)
  * generate_tokens(readline) must return bytes (#3372)
  * Add stubs for cgitb (#3368)
  * Fix HTMLParser.handle_startendtag() attrs annotation (#3366)
  * Reorder memoryview.__setitem__ overloads (#3365)
  * Add public missing asyncio stubs for windows and proactor files (#3234)
  * Add bdb stubs (#3354)
  * protobuf: Fix inadvertently deleted annotations. (#3364)
  * fixing https://github.com/python/typeshed/issues/3361 (#3362)
  * Clean up multiprocessing + shared_memory (#3351)
  * Annotations for remaining Python 3.8 additions (#3358)
  * Annotate Python 3.8 removals (#3359)
  * Remove unnecessary __all__ annotations (#3357)
  * Remove raise statements from function bodies (#3355)
  * Extract asyncio exceptions into a separate module (Python 3.8) (#3356)
  * typing.pyi: Remove verbose and rename from NamedTuple (#3352)
  * Add several Python 3.8 annotations (#3347)
  * Update 'format' README section -- don't imply it is executable (#3350)
  * Add missing exception to smtplib (#3348)
  * Ensurepip stubs (#3349)
  * find_loader() can return None (#3341)
  * Change type for urllib headers from Mapping to email.message.Message (#3345)
  * Fix argument type for logging.Formatter.formatTime (#3343)
  * protobuf: Narrow type of Message.FromString. (#3340)
  * Allow callables in _SourceObjectType (Python 2) (#3338)
  * Add assorted annotations (#3335)
  * Python3.8 additions and changes (#3337)
  * Fix an argument to csv.DictReader() (#3339)
  * protobuf: Tighten annotations for MergeFromString and ParseFromString. (#3333)
  * Update the signature of decorator.decorator (#3336)
  * message.pyi: Change HeaderType to Any (#2924)
  * Revised stubs for geoip2 third party library (#3317)
  * Mark some urllib.parse return fields optional (#3332)
  * Remove unused # type: ignore comments (#3325)
  * models.pyi: Add missing requests.Respons.next() (#3328)
  * Make it explicit that the cryptography stubs are incomplete (#3331)
  * Fix the signature of decorator.contextmanager (#3330)
  * Make 2-arg iter() retrun type match passed callable's return type (#3326)
  * Add missing Optional types in urllib.parse (#3263)
  * protobuf: Add Message.FromString static method. (#3327)
  * __init__.pyi: Add missing methods on pkg_resources.VersionConflict (#3318)
  * Minor flake8 improvements (#3324)
  * Remove a bunch of unused imports (#3323)
  * Fix return type of werkzeug's ProxyFix (#3320)
  * Add type stub for decorator lib (#3038)
  * Add `data` to UserList class, fix UserDict.data type (#3316)
  * imaplib.pyi: Add missing imaplib.IMAP4.enable() (#3314)
  * imaplib.pyi: Add ssl_context parameter for Python >= 3.3 (#3310)
  * add IncrementalNewlineDecoder constructor (#3311)
  * IncrementalNewlineDecoder.decode accepts str (#3312)
  * imaplib.pyi: Take strings as args instead of a list of strings (#3308)
  * introduce __floor__ and __ceil__ for int in Python 3 (#3306)
  * rrule.weekday(...) returns rrule.weekdays, not _common.weekdays. (#3274)
  * Fix the signature of IOBase._checkClosed(). (#3305)
  * Move cryptography from 2 to 2and3 (#3304)
  * ssl: add VerifyFlags flags and VerifyMode enum (#3302)
  * Updated maxminddb stubs to v1.5.0 (#3300)
  * builtins.pyi: Use two type vars (#3291)
  * cryptography: Return RSAPrivateKeyWithSerialization from generate_private_key. (#3296)
  * Allow callables in _SourceObjectType (#3295)
  * Remove some spurious version checks in logging (#3292)
  * Use Any instead of object in the view types for __and__ and __sub__ (#3294)
  * Add the mypyc_attr function to mypy_extensions (#3290)
  * Add http.MISDIRECTED_REQUEST introduced in 3.7 (#3293)
  * Enable --disallow-any-generics for stubs (#3288)
  * Allow passing bytes and byte string to yaml load APIs. (#3287)
  * Added stub for asyncore.socket_map, undocumented but useful (#3284)
  * Added stub for http.server.BaseHTTPRequestHandler useful undocumented fields (#3285)
  * Added stub for urllib.request.proxy_bypass() (#3283)
  * Added ConfigParser.BOOLEAN_STATES # Undocumented (#3281)
  * Fix third_party errors with --disallow-any-generics (#3278)
  * Change last asyncio.gather() overload ret. to List (#3248)
  * Modified __add__ method in tuple class (#3252)
  * Simplify Travis-CI configuration (#3220)
  * Improve the explanatory comment at the top of check_consistent.py
  * Fix some errors with --disallow-any-generics (#3276)
  * switched return_exceptions from bool to Literal for asyncio.gather (#3275)
  * Add multiprocessing.Array (#3272)
  * dir argument to tempfile functions may take PathLike (#3226)
  * Add missing default for ssl_handshake_timeout agrument (#3277)
  * Make the `value` argument to ctypes.cbool.__init__ optional. (#3273)
  * update `codecs.register` type definition (#3271)
  * Updated logging type stub (#3269)
  * Add return types for pymysql.connection.close/cursor (#3268)
  * inspect.Traceback/FrameInfo index/code_context attributes now Optional[] (#3265)
  * click: Support tuples of _ParamTypes, CliRunner fixes (#3259)
  * Define listdir in posix and import it in os. (#3258)
  * Added constructor types for click.FloatRange (#3257)
  * Added missing top-level export to click (#3256)
  * Introduce explicit `__str__` and `__repr__` for Exceptions (#3247)
  * Changed type of fieldname parameter in DictWriter __init__ method from Sequence[str] to Iterable[str]. This allows it to work with the following code: (#3253)
  * add missing errnos (#3254)
  * Changed combine method in datetime to use aliased _date and _time types (like all other methods in this class) to avoid namespace collision with date and time methods. (#3251)
  * Stubs for maxminddb added (#3245)
  * Make the type of `timeout` Optional[float] everywhere in subprocess. (#3241)
  * Copy a better definition of abstractmethod from 3/abc to 2/abc. (#3242)
  * Update and improve py_compile module stubs. (#3240)
  * Add proper support for __rtruediv__ on libpath.Path (#3236)
  * setprofile accepts None (#3239)
  * Accept bytes to several Redis client commands (#3238)
  * requests.Session.request data arg accepts an iterable of tuples (#3237)
  * Use Text for text arguments to click.[un]style (#3233)
  * Add ThreadingHTTPServer stub (#3232)
  * Add AIFC module stubs (#3075)
  * Change SyncManager behaviour when used as a context decorator (#3230)
  * fix: Add MapResult type (#3228)
  * Fix type in argparse.HelpFormatter._fill_text() (#3229)
  * Use protocol for FTP.stor* (#3227)
  * Return concrete sets from ItemsView and KeysView (#3181)
  * Allow passing str to Python 2's bytearray.extend. (#3223)
  * Mark some types as non-hashable (#3219)
  * ssl.pyi: Add functions, support Path (#3044)
  * Type response of Flask test client methods: get, post, etc. (#2904)
  * Use Literal to improve tempfile.[Named]TemporaryFile. (#3215)
  * Update pyre_extensions stub (#3214)
  * Mark ParamType.fail() as NoReturn (#3213)
  * Remove custom _Text type (#3211)
  * Make target optional in contextlib redirecting managers (#3212)
  * requests: Allow bytes for url parameters. (#3209)
  * Add unquote_to_bytes to Python 3 six.moves.urllib.parse. (#3208)
  * Add typestubs for unittest.util (#3186)
  * doctest: fix type of DocTestParser.get_doctest(lineno) (#3206)
  * Make inplace sorting require mutable sequences in bisect module (#3199)
  * Add sys.flags.utf8_mode. (#3205)
  * zipfile.ZipFile: Add start_dir attribute. (#3203)
  * create_server returns a Server, not AbstractServer (#3131)
  * cadata param can (and PEM-encoded cadata must) be unicode under PY2 (#3150)
  * Update how mock classes alias to Any (#3182)
  * adds threading related members to queue.pyi (#3198)
  * multiprocessing.Value can also take a Type (#3200)
  * Add stubs for CGIHTTPServer (#3196)
  * builtins: int.__pow__ can take a modulo argument (#3192)
  * builtins,numbers: harmonize float.__round__ and Real.__round__ (#3193)
  * builtins: add __trunc__ to int and float (#3194)
  * Remove unnecessary quotes around forward references. (#3191)
  * Make most contextmanager `__exit__` signatures return Optional[bool] (#3179)
  * Partially restore old (imprecise) signature of Match.group() (#3190)
  * Fix #3187 : Wrong Signatures in socketserver (#3189)
  * Update __import__ function annotations (#3188)
  * Fix a typo (self -> cls) in stdlib/2/subprocess.pyi. (#3185)
  * Add Match.regs (#2819)
  * Update URL: python/black → psf/black (#3180)
  * Implement ZipExtFile in the zipfile type stubs (#3074)
  * Add some redis types (#3092)
  * Widen the annotation of os.write to include buffer. (#3109)
  * Improve type of tornado.testing.gen_test. (#3174)
  * Use Literal in a few more places (#3176)
  * Improve werkzeug exceptions slightly (#3178)
  * Fix Match.group problems (#3172)
  * Move some constants from tokenize to token in Python 3.7+. (#3175)
  * make basicConfig parameters Optional[...] (#3170)
  * concurrent: add private classes and exceptions (#3169)
  * Add missing methods to asyncio stubs (#3088)
  * Improve enums (#3168)
  * Add nbytes to the memoryview definition (#3167)
  * Declare asyncio.as_completed() as taking an Iterable (#3164)
  * Add type annotations for Python 3 html.entities (#3161)
  * Precise the type of Python 2 htmlentitydefs module (#3163)
  * Remove unused import from stdlib/2/htmlentitydefs.pyi (#3162)
  * flask: allow view func body to be dict (#3149)
  * Require the newest pytype version, with a pyi parser fix. (#3160)
  * Fix type annotations for get_wch / unget_wch (#3157)
  * inspect: use more specific arg type for some source retrieve functions (#3155)
  * Add hints for 3 globals from logging/__init__.py (#3159)
  * curses: getch returns an integer (#3156)
  * Add attributes to xml.etree.ElementTree.ParseError. (#3158)
  * dateutil.rrule can take dates (#3154)
  * Remove Python 3.4 support (#3147)
  * [stdlib][3] Add missing typing.OrderedDict generic stub for Python 3.7.2 (#3153)
  * Allow function.__code__ in Python 2 (#3152)
  * Use pytype.config.Options.create() for prettier code. (#3151)
  * Fix incorrectly named parameters in logging module (#3148)
  * gettext stubs fixed (#3130)
  * Travis: run mypy with Python 3.8 as well (#3146)
  * Add zipfile.ZipFile.filename (#3104)
  * xml.etree.ElementTree: use literal type for a more precise return value for tostring() (#3120)
  * Fix __call__ type for GeneratorContextManager (#3143)
  * inspect: get{doc,comments,module,sourcefile} can return None (#3137)
  * warnings: ignore the type of category when message is a Warning (#3121)
  * Add werkzeug.middleware (#3103)
  * Fix ast.Constant availability (#3142)
  * Upgrade flake8* and isort versions (#3141)
  * json: require a JSONDecoder/JSONEncoder in cls (#3138)
  * Update google RepeatedCompositeFieldContainer (#3136)
  * faulthandler.dump_traceback_later: timeout can be float (#3134)
  * remove itertools.accumulate from Python 2 stubs (#3135)
  * Fix python 2 subprocess.Popen to produce Popen[bytes] (#3133)
  * Make python 2 subprocess consistent with python 3 (#3132)
  * Update socket exceptions (#3127)
  * Fix the definition of nsmallest() in stdlib/2 and 2and3/heapq.pyi (#3114)
  * Remove mypy new analyzer tests (#3128)
  * Add __eq__ to protobuf containers (#3126)
  * Added Optional (#3125)
  * Overload the constructor of subprocess.Popen (#3113)
  * Make SyntaxError.text be optional (#3119)
  * Re-export _curses._CursesWindow from curses (#3117)
  * Add curses.COLORS and curses.COLOR_PAIRS (#3115)
  * Update required pytype version to one that supports `async def`. (#3112)
  * Slice attributes can be of any type. (#3024)
  * sys: refine the return type of sys.exc_info() (#3111)
  * Use Literal overloads to give better types to subprocess (#3110)
  * BytesGenerator requires BinaryIO (#3106)
  * Add types to FileStorage (#3067)
  * Improving Flask stubs (#3003)
* Sat Jul 20 2019 Tomáš Chvátal <tchvatal@suse.com>
- Provide/obsolete python2-typeshed too
* Thu Jul  4 2019 mimi.vx@gmail.com
- Update to version 0.0.1+git.1562136779.4af283e1:
  * Fix HTTPConnection.putrequest parameter names (#3101)
  * Add in multiprocessing.managers.ValueProxy types (#3100)
  * PurePath methods accept os.PathLike[str] from 3.6 (#3099)
  * Fix contextlib GeneratorContextManager name for py>=3.2 (#3083)
  * QueueHandler / QueueListener accept SimpleQueue too (#3098)
  * xml.etree.ElementTree: fix missing None in get(), findtext() return type (#3093)
  * Add Generic Typing to Queue.PriorityQueue and Queue.LifoQueue in python 2 (#3036)
  * Add TLSVersion & related attributes to SSLContext (#3097)
  * Make dataclasses.Field.metadata non-optional (#3094)
  * Add undocumented methods codecs.utf_16_be_{decode,encode}. (#3091)
  * Restore default value to click.echo_via_pager (#3090)
  * Install Black and isort autoformatters (#3069)
  * itsdangerous: update JSONWebSignatureSerializer.dumps return type (#3082)
  * "key" argument of builtin function sorted should be optional in python 2.7 (#3086)
  * Fix annotation of re.Match 'lastindex' and 'lastgroup' in Python 3 (#3085)
  * fix type of loop.sock_connect (#3073)
  * Revert "Define functools.partial as overloaded function instead of its own class (#2878)" (#3077)
  * Add mp_context parameter to concurrent.futures.ProcessPoolExecutor (#3078)
  * fix ssl.Purpose type in py3 (#3054)
  * Add types and functions in types.py that are new in 3.7 (#3066)
  * Refactor tests/pytype_test.py (#3065)
  * change http.cookies.Morsel to Dict[str, Any] (#3060)
  * Represent the use of IntEnums in functions in socket.py. (#3009)
  * HTMLParser.get_starttag_text() can return None (#3072)
  * redis: Add some type hints (#3055)
  * Sync recent typing and typing_extensions updates (#3070)
  * Overload ast.parse to recognize that mode=exec means Module return. (#3039)
  * str and unicode format functions take objects (#3068)
  * ssl.pyi: fix types of cadata argument (#3063)
  * Marshal dumps/loads uses bytes (#3061)
  * Update select and selectors to use _HasFileno protocol (#3057)
  * Adding stubs for pyre_extensions (#3056)
  * Add redis stream methods to the client stubs (#3051)
  * request.pyi: Change Union[] -> Any for attributing status. (#3045)
  * Add missing path-like annotation (#3053)
  * Add a few Redis types (#3016)
  * Use type annotation syntax (#3048)
  * Mark asyncio loop parameters as Optional (#3047)
  * dateutil: byweekday can take weekday (#3046)
  * Add `copy()` method to requests.Session.headers (#3043)
  * Add missing constructor to types.CodeType. (#3040)
  * Add undocumented but used method LWPCookieJar.as_lwp_str. (#3041)
  * Add new semantic analyzer to mypy tests (#3037)
  * Add stub for queue.SimpleQueue in 3.7 (#2995)
  * Add FullLoader and FullConstructor classes to yaml (#3035)
  * Added tojson_filter and detect_encoding to flask.json (#3030)
  * Annotate HTMLParser attribute optional value (#3034)
  * Add a "pull requests welcome" batch (#3033)
  * Use custom tuple subclass for pwd.struct_passwd (#3017)
  * Make AsyncGeneratorType.aclose() properly return Awaitable[None] (#3032)
  * click: Use property decorator for read-only properties (#3028)
  * Update Click to 7.0 (#3027)
  * Move stdlib/3/curses to stdlib/2and3/curses. (#3025)
  * fix Sniffer.sniff return type (#3023)
  * Move Redis stubs to 2and3 (#3015)
  * [pyre] Adding IntVar to typing_extensions (#3008)
  * argparse.pyi: Allow Callable[[Text], _T] (#3013)
  * Make Timer args less restrictive (#3007)
  * Use typing.Text for argument types (#3000)
  * Allow is_dst=None in pytz.BaseTzInfo.localize() (#3002)
  * Add missing methods to ItemsView and KeysView, including isdisjoint (#2997)
  * Bound arguments are ordered (#2998)
  * Implement SupportsIndex (#2996)
  * Add sys.breakpointhook() and sys.__breakpointhook__ (#2991)
  * Add undocumented member glob.has_magic (#2972)
  * Add missing annotation in cmath module (#2989)
  * Remove all pyi files that use nested classes from the pytype blacklist. (#2993)
  * fix CI (#2992)
  * Convert typing.ContextManager.exit to use dunder parameter names (#2980)
  * Remove redundant variable definitions in ast module (#2986)
  * Fix typos in yaml stubs (save_* -> safe_*) (#2985)
  * Update dateutil to 2.7.5 (#2694)
  * Add functions to six.moves.urllib.request (#2982)
  * Always use fully qualified names to refer to nested classes. (#2983)
  * Have click.style return a str (#2981)
  * Add an optional opener parameter to open() function (#2977)
  * Add new show_choices argument to click options (#2978)
  * Unblacklist more third_party stubs from pytype parsing. (#2975)
  * Split unittest stubs and add a few field (#2973)
  * Add subprocess.list2cmdline for python 2 (#2971)
  * Add TypedDict to typing_extensions (#2940)
  * Add py3.7 support to Future.add_done_callback (#2970)
  * Add stub for asyncio.BaseEventLoop (#2960)
  * Add annotation for Future._callbacks (#2965)
  * add types.FunctionType.__init__ (#2968)
  * allow callables in dis() (#2969)
  * narrow signature of __contains__ for str-like classes (#2967)
  * Make pytype happy with the third_party click stubs. (#2966)
  * add autocomplete to click decorators (#2705)
  * Adjust indentation of TODOs in third_party/2/gflags.pyi. (#2964)
  * Fix Future.__init__'s loop variable annotation (#2961)
  * Add annotation to Future._loop (#2959)
  * Fix typo: __builtins__ should be __builtin__. (#2963)
  * Remove some files from pytype's third_party blacklist. (#2962)
  * Bleach stubs: fix typos, use protocol classes (#2957)
  * Define functools.partial as overloaded function instead of its own class (#2878)
  * Make the signature of ConfigParser.get() polymorphic (#2406)
  * add click.types.DateTime to click stubs (#2958)
  * yaml.dump(..., stream) is optional (#2289)
  * Switch pytype_test from a whitelist to a blacklist for third_party. (#2956)
  * unittest: Add overloads to assert(Not)AlmostEqual(s) (#2901)
  * Added defs for undocumented attrs on enums (#2941)
  * Annotate `copy` for MappingProxyType (#2955)
  * Use dunder parameter name in `_Writer.write` (#2954)
  * Use dunder parameter name in `Container.__contains__` (#2953)
  * Added termios.error (#2951)
  * Update Black URL (#2950)
  * fix type of msg argument to HTTPRedirectHandler.redirect_request (#2949)
  * click/types.pyi: Add case_sensitive wrt click 7.0 (#2948)
  * Change WatchedFileHandler to inherit from FileHandler (#2947)
  * config.pyi: Return a Thread instance (#2945)
  * add BadRequestKeyError (#2944)
  * Remove MutableMapping from requests.Session.cookies's type (#2946)
  * itertools.pyi: Replace Iterable with Iterator. (#2943)
  * Positional-only arguments for built-in functions. (#2921)
  * Add initializer for http.cookiejar.Cookie (#2932)
  * socket: add .set_inheritable() (#2935)
  * Specify default = ..., positional-only for orjson API (#2936)
  * Remove format_map from Python 2 unicode. (#2933)
  * Make shlex.shlex convertable to a list in Python 2. (#2927)
  * Correct the type signature of assertRaisesRegexp (#2926)
  * Make loop optional in asyncio.Queue (#2923)
  * locale.format_string takes strings and numbers, too. (#2922)
  * Add stub for multiprocessing.Value.get_lock() (#2920)
  * Use variable annotations everywhere (#2909)
  * KeysView and ItemsView should accecpt Iterable argument in set operation (#2906)
  * Make os.altsep Optional on non-win32 platforms (#2918)
  * Add @typing.type_check_only (#2679)
  * Fix quit's argument and return types to match those of exit. (#2915)
  * Fix TextTestResult and TextTestRunner in unittest (#2910)
  * threading.Lock issue when using it with ExitStack (#2908)
  * Add type hints for the turtle module (#2905)
  * Fix some issues with __round__ (#2907)
  * Complete the stub for _thread.pyi. (#2900)
  * flask.Flask.run: port can be str (#2903)
  * Add six.moves types for email_mime sources. (#2902)
  * reword "What to include" (#2861)
  * Fix typo in FrameType 3.7 attributes (#2899)
  * Update pytype_test to remove now-unnecessary parse-only functionality. (#2897)
  * Accept bytes as 1st argument of `simplejson.loads` (#2896)
  * Add mmap as a valid buffer type. (#2895)
  * werkzeug: ETagRequestMixin's functions are properties (#2894)
  * tempfile.mkdtemp() should return a str when passed no arguments. (#2893)
  * yaml: add full_load and full_load_all stubs (#2892)
  * Added excepthandler to ast stubfiles (#2891)
  * Add a type: ignore as a hacky workaround for some mypy bazel issues (#2887)
  * [builtins] Add 'AST' type to 'source' parameter for 'compile()' (#2889)
  * Fix a py2 parameter type in string.Template.(safe_)substitute. (#2888)
  * Add overloads for min/max that don't take default (#2885)
  * Add missing dateutil.tz.UTC (#2883)
  * Fix werkzeug.UserAgentMixin annotation (#2881)
  * [third_party/click] add Exit exception definition (#2880)
  * [re] Add attribute '_pattern_type' to re. (#2877)
  * Add missing BaseException.__suppress_context__ attribute (#2876)
  * Add missing class pdb.Pdb. (#2872)
  * Add unicode support to py2 string.Template. (#2871)
  * Add attribute queue.Queue.queue. (#2870)
  * Add tarfile.filemode. (#2869)
  * Move pydoc from 2/ to 2and3/. (#2873)
  * Remove asyncio.tasks from the pytype blacklist. (#2874)
  * Speed up pytype_test by reducing subprocess calls. (#2868)
  * move pycurl.pyi from 2 to 2and3 (#2867)
  * Remove an unused import from stdlib/3/importlib/__init__.pyi. (#2866)
  * Update signature of webbrowser.register for Python 3.7 (#2865)
  * Use protocol for print() file argument (#2848)
  * Click: add 'length' and 'label' properties to ProgressBar. (#2860)
  * Fix several Flask types (#2858)
  * Add timeit.main (#2731)
  * Support new ast features and node types introduced in Python 3.8 (#2859)
  * [traceback] Expose print_list method in traceback for python3. (#2837)
  * email.mime.application.MIMEApplication expects data to be bytes, while it should be Union[str, bytes] (#2855)
  * Add email.charset.SHORTEST, QP, BASE64 to the stub for Python 2 (#2857)
  * Make vars arguments Optional, as they default to None (#2853)
  * Add logging.Formatter.formatMessage method (#2850)
  * asyncio: make type alias private and CamelCase (#2849)
  * Add stubs for bleach (#2709)
  * [asyncio] Change _set_running_loop(loop: AbstractEventLoop) to _set_running_loop(loop: Optional[AbstractEventLoop]) (#2828)
  * Update asyncio streams stub (#2845)
  * Update attr stubs to 19.1.0 (#2846)
  * Added missing default value annotation (#2841)
  * Fix inconsistent self/cls parameter names (#2838)
  * Changed parameter name of several methods in logging module from 'lvl' to 'level' to match the implementation. Use in a keyword arg of 'lvl' results in runtime errors. (#2840)
  * Removed extraneous import statement that was redefining three symbols in markupsafe/__init__.py. This redefinition triggered type checking/linting errors. (#2842)
  * Add isascii methods to str, bytes, and bytearray [Python 3.7]. (#2834)
  * Improve min/max (#2833)
  * Prefer Mapping to Dict for input of csv DictWriter methods. (#2829)
  * Add sunder names to enum (#2822)
  * Make 2.7's json.load use a protocol for fp (#2826)
  * Add itermonthdays3 and itermonthdays4, fix incorrect 'cssclass_today' (#2825)
  * multiprocessing.spawn submodule and multiprocessing.pool stubs (#2823)
  * make IMapIterator a subclass of Iterator (#2814)
  * Make urllib2.urlopen return a non-optional addinfourl (#2821)
  * fix some minor lint errors (#2820)
  * Revert "Fixing signature for Mapping.get's default parameter (#2810)" (#2817)
  * README.md suggests running tests with PYTHONPATH instead of MYPYPATH (#2813)
  * Fix signature of asyncio.create_connection. (#2756)
  * fix undefined name in flask stub (#2811)
  * fix missing space in imghdr (#2812)
  * Genericize types for stringly typed methods on google.protobuf.Message (#2807)
  * Fixing signature for Mapping.get's default parameter (#2810)
  * Add Restart to pdb.pyi (#2805)
  * Remove redundant definition of ast.PyCF_ONLY_AST (#2803)
  * Add some urllib2 annotations (#2688)
  * socket: timeout may be None (#2801)
  * Add some missing annotations in cyaml (#2769)
  * Fix named tuple name in posix.pyi (#2800)
  * Remove an unnecessary entry from the pytype blacklist. (#2799)
  * Fix Flask stubs for dispatch_request (#2796)
  * Remove pytype workaround in os/__init__.pyi. (#2797)
* Tue Feb 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix the URL and set author in changelog entries
* Thu Feb 14 2019 mcepl@suse.com
- Update to version 0.0.1+git.1550076324.0989d950:
  * Fix groupby with key=None (#2794)
  * root_path cannot be None (#2792)
  * Added `Optional[]` around the `itertools.groupby()` `key` attribute to allow `None` to pass the type (#2790)
  * Fix Flask.config annotation (#2787)
  * Add stubs for HTTP Handler classes in py2/urllib2 & py3/urllib.request (#2710)
  * Make AsyncGenerator.aclose() properly return Awaitable[None] (#2786)
  * Add type hints for orjson (#2747)
  * Some small tweaks to Werkzeug stubs: (#2784)
  * Make `NamedTuple` accept `Text` names (#2762)
  * decorators.pyi: Add overload to option() (#2671)
  * __init__.pyi: Add __getitem__() to stat_result() (#2753)
  * Support *contiguous attributes of memoryview. (#2755)
  * Use a more accurate type for jwt.decode (#2765)
  * Fix signature of asyncio.create_server. (#2763)
  * Improve the stubs in charset.pyi under python3. (#2768)
  * requests.auth.AuthBase.__call__ deals with PreparedRequest. (#2759)
  * Support the errors arg in codecs factory functions. (#2752)
  * gflags: Add DEFINE_multi_enum. (#2783)
  * Add  types to some cross-platform functions in the platform library (#2781)
  * Make SyntaxError.offset be optional (again) (#2782)
  * Update models.pyi (#2780)
  * Update stubgen link and add a bit more info (#2779)
  * Add hidden and deprecated click.Command options (#2778)
  * Add type annotation for collections.deque.__iadd__ (#2774)
  * pkg_resources: fix stub for get_metadata_lines (#2776)
  * pkg_resources Add PKG_INFO str attribute for Distribution class (#2775)
  * Create stubs for Flask (#2740)
  * builtins.pyi: Update __iadd__() and imul() in class list (#2754)
  * Fix six.raise_from value type (#2746)
  * Add SSLCertVerificationError fields (#2745)
  * logging: inherit TimedRotatingFileHandler from Handler (#2738)
  * Add missing explicit Optional to stubs for the xml.etree package. (#2734)
  * Fix `logging.getLevelName()` type hints (#2730)
  * add back StopIteration.value in Python 3 (#2744)
  * As of Python 3.6 dump_stats method allows PathLike object to be passed. (#2741)
  * Make metavar in argparse be Optional (#2739)
  * Fix type of indent in JSONEncoder (#2737)
  * Make ZipFile.NameToInfo use Text as the key type (#2736)
  * Fix the type of ord on python 2 (#2735)
  * Use a more accurate type for predicates in itertools (#2732)
  * Add SSLCertVerificationError for 3.7+ (#2729)
  * Update sqlite3 types to include extensions (#2728)
  * Use overlapped signatures of _winapi functions (#2723)
  * Fix unittest.TestCase assert methods' argument names (#2724)
  * Add stubs to classes in zipfile to better enable subclassing (#2707)
  * LoggerAdapter.log argument lvl -> level (#2722)
  * Sync attr stubs from attrs github repo (#2720)
  * Fixing type for asyncio.StreamWriter reader init parameter (#2719)
  * Make appropriate ast methods generic (#2715)
  * Add missing `currentframe` to `logging` module (#2712)
  * Merge Python 2 and 3 builtins.pyi (#2533)
  * Complete unittest.TextTestResult stubs (#2700)
  * Add missing attributes of type (#2544)
  * socket: Some more address typing (#2695)
  * Set correct type for _subparsersaction.choices (#2702)
  * Make mypy aware of IMapUnorderedIterator (#2701)
  * loop argument to asyncio.ensure_future is Optional (#2708)
  * Add stubs for six.ensure_{binary,str,text} functions (#2704)
  * Add Str.kind field to typed_ast stubs (#2699)
  * Add members marker and unsafe_name to pkg_resources.Requirement (#2693)
  * Add stubs for tabulate (#2384)
  * bytes/bytearray.startswith fixes (#2696)
  * Add missing ENOTSUP alias to errno (#2692)
  * Add pynamodb.models.Model.get_attribute and narrow down the type (#2689)
  * Logging (#2687)
  * macpath, os/path, posixpath and ntpath should basically be the same files (#2637)
  * Fix typo for `Message.add_attachment` in message.pyi (#2697)
  * Move posix.stat_result to os.stat_result on python 3 (#2683)
  * Task.current_task() and Task.all_tasks() have an optional loop parameter (#2690)
  * urllib2: timeout: int -> Optional[float] (#2685)
  * Fix signature of ConfigParser's dict_type argument (#2684)
  * Add get_loop() to asyncio.Future [Python 3.7] (#2680)
  * Add contextlib.nullcontext [Python 3.7]. (#2677)
  * Fix property annotation in `third_party/2and3/boto/connection.pyi` (#2675)
  * decimal.pyi: Add overload for Decimal.__round__() (#2674)
  * Fix signature of TypedDict has_key() (#2672)
  * Add 'Literal[...]' to typing_extension stubs (#2664)
  * Add mypy fallback class for TypedDict methods to mypy_extensions (#2670)
  * Guidelines for incomplete stubs (#2661)
  * Tweak how ast.pyi imports typing (#2668)
  * ast.pyi: Fix return type of generic_visit() (#2667)
  * [protobuf] add deterministc option (#2666)
  * Replace Loader with PEP 451 _Loader protocol in _importlib_modulespec.pyi annotations. (#2626)
  * builtins.pyi: Return complex from __(r)pow__()  (#2662)
  * Make contribution guidelines state when to use (and not use) 'Any' (#2540)
  * Reference black, split long functions (#2651)
  * itertools.pyi: Allow omitting repeat argument in Python 3 (#2659)
  * Stop inheriting Sized in collection ABCs (#2658)
  * Revert "Move Sized earlier in the bases of Sequence (#2602)" (#2657)
  * Properly type the ToJsonString method of time well known types in google protobuf (#2656)
  * decorators.pyi: Add Any angument to Callable[] (#2654)
  * Revert "fix list concatenation (#2404)" (#2653)
  * Re-export pyexpat instead of using check_consistency (#2649)
  * staticmethod and classmethod can wrap any callable (#2650)
  * Unicode fixes for url2pathname() and pathname2url() (#2555)
  * Fix handling of logging args (#2635)
  * threading.pyi: Add currentThread for all versions (#2647)
  * [gflags] add known_only arg to __call__ (#2646)
  * __init__.pyi: Fix dump() (#2640)
  * yaml: Add __version__ attribute (#2636)
  * types.CodeType.co_filename isn't Optional. (#2639)
  * Improve overloads of parse_args() -- it never returns None (#2643)
  * Change argument type for xml.etree.ElementTree.iselement() to object (#2642)
  * Add stubs for the faulthandler stdlib module (#2627)
  * Add posix attributes for Python 3 (#2631)
  * Fix return type of datetime.datetime.dst (#2634)
  * Add __getnewargs__ to float, int, bool, str, bytes, unicode (#2632)
  * Added cyaml.pyi (#2613)
  * zipfile.ZipInfo.__init__ is the same on 2/3 (#2628)
  * Remove unneeded ignores (#2624)
  * sudo is not required anymore (#2618)
  * add __setattr__ to optparse.Values (#2622)
  * Update types for requests.adapters (#2614)
  * Add some distutils.dist.Distribution attrs (#2620)
  * Add stub for pytz.VERSION (#2619)
  * Added logging port constants to logging.handlers stub (#2617)
  * Accept upstream stubs when receiving no response (#2608)
  * Merge Python 2 and 3 versions of itsdangerous (#2564)
  * Add complete annotations to builtins.compile. (#2606)
  * Let ctypes._CData.from_buffer[_copy] accept any buffer object (#2610)
  * Replace non-ellipsis default arguments (#2550)
  * Fix stub for SpooledTemporaryFile (#2452)
  * Allow array[int] as a valid input to struct.unpack(). (#2586)
  * Document the Python 3.7 variant of subprocess.check_output (#2592)
  * Fix return annotation for asyncio.as_completed() (#2600)
  * Relax type for click.echo. (#2607)
  * Add optimize parameter to builtins.compile. (#2605)
  * Fix two small issues in `ctypes.Array` stubs (#2599)
  * Fix the return type for unittest.TestCase.run() (#2603)
  * Move Sized earlier in the bases of Sequence (#2602)
  * Expand Python 2's urllib.addbase definition. (#2601)
  * Annotate some missing http client and urllib APIs. (#2582)
  * Add missing stubs for multiprocessing.connection module. (#2596)
  * unittest.TestCase.assertRaises(): BaseException (#2594)
  * Fix typo in typing.pyi (#2595)
  * fix list concatenation (#2404)
  * Add options and extensions to google protobuf messages. (#2589)
  * Strengthen typing of datetime methods of Google protobuf's Timestamp. (#2590)
  * Simplify base64 input and output parameters. (#2587)
  * deque init() optional maxlen (#2585)
  * Make inspect.unwrap() stop argument optional. (#2583)
  * Add context manager to tarfile.TarFile (#2579)
  * Correct the param type for mapPriority (#2578)
  * Remove label descriptions from CONTRIBUTING (#2572)
  * Make _winapi.SetNamedPipeHandleState args Optional (#2571)
  * Add overrides for the methods 'readlines' and 'writelines' in TextIOBase. (#2551)
  * unittest: Complete assertRaisesRegex (#2568)
  * correct parse_args namespace attribute (#2566)
  * Remove version guard (#2565)
  * Remove third_party/3/enum.py (#2563)
  * Fix return annotation for loop.call_later() and loop.call_at() (#2559)
  * Fix return of patch() and patch.multiple() (#2520)
  * Make SyntaxError.offset be optional (#2557)
  * Fix py3 types of inspect.FullArgSpec.var(args|kw) (#2556)
  * Make backlog parameter optional in listen method (#2553)
  * Add is_dir method to ZipInfo class (#2554)
  * Flake8 fixes (#2549)
  * Fix email.parser.BytesParser and BytesHeaderParser method args (#2548)
  * Update to flake8 3.6.0 (#2547)
  * Allow json.dump to dump to BinaryIO again (#2546)
  * Make os.dup2 return int on Python 3.7 (#2543)
  * os.DirEntry.stat() accepts a follow_symlinks keyword argument (#2538)
  * Annotate jwt.algorithms (#2532)
  * fix lint error (#2541)
  * Annotate werkzeug wrap_file() and FileWrapper (#2519)
  * Rework .travis.yml and run with Python 3.7 where possible (#2536)
  * Makes enums accept objects in the argument type (#2539)
  * Fix typo in mmap const (#2537)
  * Add attributes to int and float (#2529)
  * Fix pytype test output (#2534)
  * Add cr_await, cr_code, cr_frame and cr_running to Coroutine (#2530)
  * Update PyJWT's exceptions (#2522)
  * Fix return type of ast.NodeTransformer.generic_visit (#2486)
  * loop argument for set_event_loop() is optional, it can be None (#2525)
  * Add UserString and UserList data attribute (#2518)
  * Add stub for pathlib2.Path.__div__ (#2507)
  * ImportFrom level cannot be optional (#2517)
  * click.option's defined type as return type of callable (#2505)
* Sat Oct 13 2018 mcepl@suse.com
- Update to version 0.0.1+git.1539385126.cec22025:
  * Widen the type of the file argument to Python 2's json.dump. (#2516)
  * Fix _StrType in difflib in Python 2. (#2514)
  * Set urllib.parse.urljoin url argument to optional (#2513)
  * Inherit `InstanceType` from `object` (#2511)
  * Make csv.reader take Iterator[Text] argument instead of Iterator[str]. (#2508)
  * skip .git files from linting with flake8 (#2506)
  * Make _NetlocResultMixinBytes derive from _NetlocResultMixinBase[bytes], not [str] (#2503)
  * fix typing.Pattern in Python 2 (#2219)
  * Make 'datetime' a subclass of 'date'. (#2488)
  * Add new gflags names. (#2489)
